P4 to Git Change 1549012 by lmoriche@lmoriche_opencl_dev2 on 2018/05/02 16:56:02

SWDEV-145570 - [HIP] - Add hipMemset2DAsync, fix the HCC triple for device binaries (make sure to update to the latest HCC).

Affected files ...

... //depot/stg/opencl/drivers/opencl/api/hip/hip_hcc.def.in#4 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_hcc.map.in#4 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_memory.cpp#17 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_platform.cpp#10 edit


[ROCm/clr commit: 57a05ba4d5]
Αυτή η υποβολή περιλαμβάνεται σε:
foreman
2018-05-02 19:14:52 -04:00
γονέας 8bd2c78f00
υποβολή a6af6ea8d7
4 αρχεία άλλαξαν με 12 προσθήκες και 1 διαγραφές
@@ -98,6 +98,7 @@ hipMemPtrGetInfo
hipMemset hipMemset
hipMemset2D hipMemset2D
hipMemsetAsync hipMemsetAsync
hipMemset2DAsync
hipMemsetD8 hipMemsetD8
hipModuleGetFunction hipModuleGetFunction
hipModuleGetGlobal hipModuleGetGlobal
@@ -99,6 +99,7 @@ global:
hipMemset; hipMemset;
hipMemset2D; hipMemset2D;
hipMemsetAsync; hipMemsetAsync;
hipMemset2DAsync;
hipMemsetD8; hipMemsetD8;
hipModuleGetFunction; hipModuleGetFunction;
hipModuleGetGlobal; hipModuleGetGlobal;
@@ -958,6 +958,15 @@ hipError_t hipMemset2D(void* dst, size_t pitch, int value, size_t width, size_t
return hipSuccess; return hipSuccess;
} }
hipError_t hipMemset2DAsync(void* dst, size_t pitch, int value, size_t width, size_t height,
hipStream_t stream) {
HIP_INIT_API(dst, pitch, value, width, height, stream);
assert(0 && "Unimplemented");
return hipErrorUnknown;
}
hipError_t hipMemsetD8(hipDeviceptr_t dst, unsigned char value, size_t sizeBytes) { hipError_t hipMemsetD8(hipDeviceptr_t dst, unsigned char value, size_t sizeBytes) {
HIP_INIT_API(dst, value, sizeBytes); HIP_INIT_API(dst, value, sizeBytes);
@@ -40,7 +40,7 @@ struct __CudaFatBinaryWrapper {
#define CLANG_OFFLOAD_BUNDLER_MAGIC_STR "__CLANG_OFFLOAD_BUNDLE__" #define CLANG_OFFLOAD_BUNDLER_MAGIC_STR "__CLANG_OFFLOAD_BUNDLE__"
#define OPENMP_AMDGCN_AMDHSA_TRIPLE "openmp-amdgcn--amdhsa" #define OPENMP_AMDGCN_AMDHSA_TRIPLE "openmp-amdgcn--amdhsa"
#define HCC_AMDGCN_AMDHSA_TRIPLE "hcc-amdgcn--amdhsa" #define HCC_AMDGCN_AMDHSA_TRIPLE "hcc-amdgcn-amd-amdhsa-"
struct __ClangOffloadBundleDesc { struct __ClangOffloadBundleDesc {
uint64_t offset; uint64_t offset;